====
YAPC
====

|Language|
|License|
|Documentation Status|

.. |Language| image:: https://img.shields.io/badge/python-v3.8-green.svg
   :target: https://www.python.org  /

.. |License| image:: https://img.shields.io/github/license/tsutterley/yapc
   :target: https://github.com/tsutterley/yapc/blob/main/LICENSE

.. |PyPI Version| image:: https://img.shields.io/pypi/v/pyYAPC.svg
   :target: https://pypi.python.org/pypi/pyYAPC/

.. |Documentation Status| image:: https://readthedocs.org/projects/yapc/badge/?version=latest
   :target: https://yapc.readthedocs.io/en/latest/?badge=latest

Python version of the NASA Goddard Space Flight Center YAPC (*"Yet Another Photon Classifier"*) Program.
YAPC is a prototype photon classifer for the NASA ICESat-2 ATL03 Global Geolocated Photon product.

- https://icesat-2.gsfc.nasa.gov
- https://icesat-2-scf.gsfc.nasa.gov
- https://nsidc.org/data/icesat-2/

Dependencies
############

 - `numpy: Scientific Computing Tools For Python <https://numpy.org>`_
 - `cython: C-extensions for Python <http://cython.org/>`_
 - `h5py: Python interface for Hierarchal Data Format 5 (HDF5) <http://h5py.org>`_
 - `scikit-learn: Machine Learning in Python <https://scikit-learn.org/stable/index.html>`_
 - `future: Compatibility layer between Python 2 and Python 3 <http://python-future.org/>`_

Download
########

| The program homepage is:
| https://github.com/tsutterley/yapc
| A zip archive of the latest version is available directly at:
| https://github.com/tsutterley/yapc/archive/main.zip

Credits
#######

YAPC was devised and is being developed by Jeff Lee (NASA Goddard Space Flight Center).
This project contains work and contributions from the `scientific community <./CONTRIBUTORS.rst>`_.

Disclaimer
##########

This program is not sponsored or maintained by the Universities Space Research Association (USRA) or NASA.
It is provided here for your convenience but *with no guarantees whatsoever*.

License
#######

The content of this project is licensed under the
`Creative Commons Attribution 4.0 Attribution license <https://creativecommons.org/licenses/by/4.0/>`_
and the source code is licensed under the `MIT license <LICENSE>`_.
